@@ -95,7 +95,7 @@ class Commands(object):
         
     def search(self, search_term=None, state='open', verbose=False, **kwargs):
         if not search_term:
-            example = "gh-issues search experimental"
+            example = "gh-i search experimental"
             msg = "error: search term required\nexample: %s" % example
             print msg
             sys.exit(1)
@@ -136,7 +136,7 @@ class Commands(object):
                 print # new line between states
         
     def show(self, number=None, webbrowser=False, **kwargs):
-        validate_number(number, example="gh-issues show 1")
+        validate_number(number, example="gh-i show 1")
         if webbrowser:
             issue_url_template = "http://github.com/%s/%s/issues/%s/find"
             issue_url = issue_url_template % (self.user, self.repo, number)
@@ -154,21 +154,21 @@ class Commands(object):
         pprint_issue(issue)
         
     def close(self, number=None, **kwargs):
-        validate_number(number, example="gh-issues close 1")
+        validate_number(number, example="gh-i close 1")
         result = self.__submit('close', number)
         issue = get_key(result, 'issue')
         print
         pprint_issue(issue)
         
     def reopen(self, number=None, **kwargs):
-        validate_number(number, example="gh-issues reopen 1")
+        validate_number(number, example="gh-i reopen 1")
         result = self.__submit('reopen', number)
         issue = get_key(result, 'issue')
         print
         pprint_issue(issue)
         
     def edit(self, number=None, **kwargs):
-        validate_number(number, example="gh-issues edit 1")
+        validate_number(number, example="gh-i edit 1")
         gh_issue = self.__get_issue(number)
         output = {'title': gh_issue['title'], 'body': gh_issue['body']}
         post_data = create_edit_issue(gh_issue)
@@ -182,11 +182,11 @@ class Commands(object):
         pprint_issue(issue)
         
     def label(self, command, label, number=None, **kwargs):
-        validate_number(number, example="gh-issues label %s %s 1" % (command,
+        validate_number(number, example="gh-i label %s %s 1" % (command,
             label))
         if command not in ['add', 'remove']:
             msg = "label command should use either 'add' or 'remove'\n"\
-                "example: gh-issues label add %s %s" % (label, number)
+                "example: gh-i label add %s %s" % (label, number)
             raise Exception(msg)
         label = urllib.quote(label)
         label = label.replace(".", "%2E") # this is not done by urllib.quote
@@ -200,7 +200,7 @@ class Commands(object):
             print "no labels found for issue #%s" % number
         
     def comment(self, number=None, **kwargs):
-        validate_number(number, example="gh-issues comment 1")
+        validate_number(number, example="gh-i comment 1")
         gh_issue = self.__get_issue(number)
         comment = create_comment(gh_issue)
         post_data = {'comment': comment}
